includeInitialValueInHistory property
bool
get
includeInitialValueInHistory
inherited
Whether to include the initial value in the undo history.
true by default, override and set to false if the initial value should
be treated like temporaryValue.
Implementation
@protected
bool get includeInitialValueInHistory => true;